Documentation
¶
Overview ¶
Package sns is a generated GoMock package.
Index ¶
- type Client
- type MockClient
- type MockClientMockRecorder
- type MockclientInterface
- func (m *MockclientInterface) CreateTopic(input *sns.CreateTopicInput) (*sns.CreateTopicOutput, error)
- func (m *MockclientInterface) EXPECT() *MockclientInterfaceMockRecorder
- func (m *MockclientInterface) GetTopicAttributes(input *sns.GetTopicAttributesInput) (*sns.GetTopicAttributesOutput, error)
- func (m *MockclientInterface) ListTopics(input *sns.ListTopicsInput) (*sns.ListTopicsOutput, error)
- func (m *MockclientInterface) Publish(input *sns.PublishInput) (*sns.PublishOutput, error)
- type MockclientInterfaceMockRecorder
- func (mr *MockclientInterfaceMockRecorder) CreateTopic(input interface{}) *gomock.Call
- func (mr *MockclientInterfaceMockRecorder) GetTopicAttributes(input interface{}) *gomock.Call
- func (mr *MockclientInterfaceMockRecorder) ListTopics(input interface{}) *gomock.Call
- func (mr *MockclientInterfaceMockRecorder) Publish(input interface{}) *gomock.Call
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client interface {
Publish(input *sns.PublishInput) (*sns.PublishOutput, error)
Lookup(topic string) (*sns.Topic, error)
CreateTopic(input *sns.CreateTopicInput) (*sns.CreateTopicOutput, error)
}
func NewSNSClient ¶
type MockClient ¶
type MockClient struct {
// contains filtered or unexported fields
}
MockClient is a mock of Client interface.
func NewMockClient ¶
func NewMockClient(ctrl *gomock.Controller) *MockClient
NewMockClient creates a new mock instance.
func (*MockClient) CreateTopic ¶
func (m *MockClient) CreateTopic(input *sns.CreateTopicInput) (*sns.CreateTopicOutput, error)
CreateTopic mocks base method.
func (*MockClient) EXPECT ¶
func (m *MockClient) EXPECT() *MockClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockClient) Lookup ¶
func (m *MockClient) Lookup(topic string) (*sns.Topic, error)
Lookup mocks base method.
func (*MockClient) Publish ¶
func (m *MockClient) Publish(input *sns.PublishInput) (*sns.PublishOutput, error)
Publish mocks base method.
type MockClientMockRecorder ¶
type MockClientMockRecorder struct {
// contains filtered or unexported fields
}
MockClientMockRecorder is the mock recorder for MockClient.
func (*MockClientMockRecorder) CreateTopic ¶
func (mr *MockClientMockRecorder) CreateTopic(input interface{}) *gomock.Call
CreateTopic indicates an expected call of CreateTopic.
func (*MockClientMockRecorder) Lookup ¶
func (mr *MockClientMockRecorder) Lookup(topic interface{}) *gomock.Call
Lookup indicates an expected call of Lookup.
func (*MockClientMockRecorder) Publish ¶
func (mr *MockClientMockRecorder) Publish(input interface{}) *gomock.Call
Publish indicates an expected call of Publish.
type MockclientInterface ¶
type MockclientInterface struct {
// contains filtered or unexported fields
}
MockclientInterface is a mock of clientInterface interface.
func NewMockclientInterface ¶
func NewMockclientInterface(ctrl *gomock.Controller) *MockclientInterface
NewMockclientInterface creates a new mock instance.
func (*MockclientInterface) CreateTopic ¶
func (m *MockclientInterface) CreateTopic(input *sns.CreateTopicInput) (*sns.CreateTopicOutput, error)
CreateTopic mocks base method.
func (*MockclientInterface) EXPECT ¶
func (m *MockclientInterface) EXPECT() *MockclientInterfaceMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockclientInterface) GetTopicAttributes ¶
func (m *MockclientInterface) GetTopicAttributes(input *sns.GetTopicAttributesInput) (*sns.GetTopicAttributesOutput, error)
GetTopicAttributes mocks base method.
func (*MockclientInterface) ListTopics ¶
func (m *MockclientInterface) ListTopics(input *sns.ListTopicsInput) (*sns.ListTopicsOutput, error)
ListTopics mocks base method.
func (*MockclientInterface) Publish ¶
func (m *MockclientInterface) Publish(input *sns.PublishInput) (*sns.PublishOutput, error)
Publish mocks base method.
type MockclientInterfaceMockRecorder ¶
type MockclientInterfaceMockRecorder struct {
// contains filtered or unexported fields
}
MockclientInterfaceMockRecorder is the mock recorder for MockclientInterface.
func (*MockclientInterfaceMockRecorder) CreateTopic ¶
func (mr *MockclientInterfaceMockRecorder) CreateTopic(input interface{}) *gomock.Call
CreateTopic indicates an expected call of CreateTopic.
func (*MockclientInterfaceMockRecorder) GetTopicAttributes ¶
func (mr *MockclientInterfaceMockRecorder) GetTopicAttributes(input interface{}) *gomock.Call
GetTopicAttributes indicates an expected call of GetTopicAttributes.
func (*MockclientInterfaceMockRecorder) ListTopics ¶
func (mr *MockclientInterfaceMockRecorder) ListTopics(input interface{}) *gomock.Call
ListTopics indicates an expected call of ListTopics.
func (*MockclientInterfaceMockRecorder) Publish ¶
func (mr *MockclientInterfaceMockRecorder) Publish(input interface{}) *gomock.Call
Publish indicates an expected call of Publish.